.. _installation_guide:

Installation Guide
==================


Installing with PIP
-------------------

The easiest way to install **homely** is using ``pip``::

    pip install homely --user

If your system doesn't have ``pip`` installed, you can follow these
`installation instructions for pip
<https://pip.pypa.io/en/stable/installing/>`_.

You can use ``homely --version`` to check that you have the latest version
installed:

.. parsed-literal::

    $ homely --version
    homely |homely_version|
    

Python 2 or Python 3?
---------------------

I highly recommend installing **homely** using python3 since python3 is so much more feature-rich than python2, but if you *do* need to install under python2, check the :any:`python2` page for important notes.

If your system has python3 but not ``pip3``, you can get it by running ``python3 -m ensurepip --user`` or following the `installation instructions for pip <https://pip.pypa.io/en/stable/installing/>`_.
